@@ -8,7 +8,7 @@ from .base import SessionMiddleware
 def __getattr__(name: str) -> Any:
     """Provide lazy importing as per https://peps.python.org/pep-0562/"""
 
-    if name != "SessionCookieConfig":
+    if name != "CookieBackendConfig":
         raise AttributeError(f"Module {__package__} has no attribute {name}")
 
     from .cookie_backend import CookieBackendConfig
@@ -16,7 +16,7 @@ def __getattr__(name: str) -> Any:
     warn_deprecation(
         deprecated_name=f"{name} from {__package__}",
         kind="import",
-        alternative="'from startlite.middleware.sessions.cookie_backend import CookieBackendConfig'",
+        alternative="'from starlite.middleware.session.cookie_backend import CookieBackendConfig'",
         version="1.47.0",
     )
 
